package de.hawhamburg.reachability.properties.json;

import java.util.Map;

import de.hawhamburg.lifecycle.data.JsonLPObject;
import de.hawhamburg.reachability.conf.enumeration.ConfigType;

/**
 * Properties change request JSON message object.<br><br>
 * 
 * This class represents the structure of the JSON messages which describes a properties change request related to this 
 * reachability agent. This messages will provide the ability to change defined configuration parameters.
 * 
 * @author  {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_AUTHOR} 
 * @version {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_VERSION}
 */
public class JsonRAPropertiesChange extends JsonLPObject {
    
    /**
     * The general typ of propertie (e.g. SYSTEM or REASONER).
     */
    public ConfigType Type;
    
    /**
     * The service state reference (entitles for change).
     */
    public String ServiceStateReference;

    /**
     * The properties which shall be changed as {@link Map} of {@link String} (property) to {@link String} (new value).
     */
    public Map<String, String> Properties;
    
    /**
     * Public default constructor to create instances of this class.
     */
    public JsonRAPropertiesChange() { }
}
