package de.hawhamburg.reachability.util;

/**
 * Utility functions related to common project issues.<br><br>
 * 
 * This utility class provides some fancy utility methods related to common project issue handling.
 * 
 * @author  {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_AUTHOR} 
 * @version {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_VERSION}
 */
public final class ProjectUtil {

    /**
     * Prevent instance creation of this utility class.
     */
    private ProjectUtil() { }
    
    /**
     * Checks if a certain class (supplied as {@link String}) exists within the project.
     * 
     * @param clazz     The class as {@link String} which shall be checked.
     * @return          <code>true</code> if the class exists, otherwise <code>false</code>.
     */
    public static boolean classExists(final String clazz) {
        try {
            Class.forName(clazz, false, ClassLoader.getSystemClassLoader());
        } catch (ClassNotFoundException e) {
            return false;
        }
        return true;
    }
    
    /**
     * Converts a string to a certain class, if possible. Supported target classes are: String, Double, Integer, Long
     * and Boolean.
     * 
     * @param <T>               The class to which the string shall be converted.
     * @param source            The {@link String} which shall be converted.
     * @param clazz             The class type to which the {@link String} shall be converted.
     * @return                  The result of this conversion.
     */
    @SuppressWarnings("unchecked")
    public static <T> T convertString(final String source,
                                      final Class<T> clazz) {
        T result = null;
        
        // Configuration file loaded?
        if (source != null) {
            // String?
            if (clazz.equals(String.class)) {
                return (T) source;
            }
            
            try {
                // Integer?
                if (clazz.equals(Integer.class)) {
                    result = (T) Integer.valueOf(source);
                }
                
                // Double?
                if (clazz.equals(Double.class)) {
                    result = (T) Double.valueOf(source);
                }
                
                // Long?
                if (clazz.equals(Long.class)) {
                    result = (T) Long.valueOf(source);
                }
                
                // Boolean?
                if (clazz.equals(Boolean.class)) {
                    result = (T) Boolean.valueOf(source);
                }
            } catch (NumberFormatException e) {
                OutputUtil.error("[NumberFormatException] " + e.getMessage());
            }
        }
        
        return result;
    }
}
